==> centercontrol-service-2.0.2-20201209.052421-7-sources.jar: com/bizvane/centercontrolservice/interfaces/SysCompanyFusionPayRecordService.java <==
package com.bizvane.centercontrolservice.interfaces;

import com.bizvane.centercontrolservice.models.po.SysCompanyFusionPayRecordPo;
import com.bizvane.centercontrolservice.models.vo.*;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.CtrlAccountPO;
import com.bizvane.utils.tokens.SysAccountPO;
import com.github.pagehelper.PageInfo;

public interface SysCompanyFusionPayRecordService {

    /**
     * 获取所有聚合支付记录
     */
    PageInfo<SysCompanyFusionPayRecordVo> getFusionPayRecordByCtrlAccount(SysCompanyFusionPayRecordSearchVo sysCompanyFusionPayRecordSearchVo, CtrlAccountPO ctrlAccountPO);

    /**
     * 获取企业下所有聚合支付记录
     */
    PageInfo<SysCompanyFusionPayRecordVo> getFusionPayRecordByCompanyId(SysCompanyFusionPayRecordSearchVo sysCompanyFusionPayRecordSearchVo);


    /**
     * 审核支付宝服务商-初审
     */
    ResponseData firstAuditFusionPayRecordAlipayProviders(AlipayProvidersBizvaneAuditVo alipayProvidersAuditVo, CtrlAccountPO ctrlAccountPO);

    /**
     * 审核支付宝服务商-复审
     */
    ResponseData secondAuditFusionPayRecordAlipayProviders(AlipayProvidersPlatformAuditVo alipayProvidersPlatformAuditVo, CtrlAccountPO ctrlAccountPO);

    /**
     * 更新聚合支付记录-备注名
     */
    ResponseData modifyFusionPayRecordRemarkName(SysCompanyFusionPayRecordPo sysCompanyFusionPayRecordPo, CtrlAccountPO ctrlAccountPO, SysAccountPO stageUser);

    /**
     * 新增支付宝商户
     */
    ResponseData addAlipayMerchant(FusionPayAlipayMerchantVo fusionPayAlipayMerchantVo, CtrlAccountPO ctrlAccountPO, SysAccountPO stageUser);

    /**
     * 更新支付宝商户
     */
    ResponseData modifyAlipayMerchant(FusionPayAlipayMerchantVo fusionPayAlipayMerchantVo, CtrlAccountPO ctrlAccountPO, SysAccountPO stageUser);

    /**
     * 新增支付宝服务商
     */
    ResponseData addAlipayProviders(FusionPayAlipayProvidersVo fusionPayAlipayProvidersVo, CtrlAccountPO ctrlAccountPO, SysAccountPO stageUser);

    /**
     * 更新支付宝服务商
     */
    ResponseData modifyAlipayProviders(FusionPayAlipayProvidersVo fusionPayAlipayProvidersVo, CtrlAccountPO ctrlAccountPO, SysAccountPO stageUser);


    /**
     * 新增微信商户
     */
    ResponseData addWxPayMerchant(FusionPayWxPayMerchantVo fusionPayWxPayMerchantVo, CtrlAccountPO ctrlAccountPO, SysAccountPO stageUser);

    /**
     * 修改微信商户
     */
    ResponseData modifyWxPayMerchant(FusionPayWxPayMerchantVo fusionPayWxPayMerchantVo, CtrlAccountPO ctrlAccountPO, SysAccountPO stageUser);


    /**
     * 新增微信银联
     */
    ResponseData addWxPayUnion(FusionPayWxPayUnionVo fusionPayWxPayUnionVo, CtrlAccountPO ctrlAccountPO, SysAccountPO stageUser);

    /**
     * 修改微信银联w
     */
    ResponseData modifyWxPayUnion(FusionPayWxPayUnionVo fusionPayWxPayUnionVo, CtrlAccountPO ctrlAccountPO, SysAccountPO stageUser);

    /**
     * 查询聚合支付信息
     */
    ResponseData<FusionPayRecordWrapperVo> getFusionPayInfoByRecordId(FusionPayRecordRequestWrapperVo fusionPayRecordRequestWrapperVo);

    /**
     * 支付宝服务商授权回调成功更新数据
     */
    Integer modifyAlipayProvidersAppIdByPid(String pid,String appId,Integer alipayProvidersId);
}

==> centercontrol-service-2.0.2-20201209.094804-9-sources.jar: com/bizvane/centercontrolservice/interfaces/SysCompanyFusionPayRecordService.java <==
package com.bizvane.centercontrolservice.interfaces;

import com.bizvane.centercontrolservice.models.po.SysCompanyFusionPayRecordPo;
import com.bizvane.centercontrolservice.models.vo.*;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.CtrlAccountPO;
import com.bizvane.utils.tokens.SysAccountPO;
import com.github.pagehelper.PageInfo;

public interface SysCompanyFusionPayRecordService {

    /**
     * 获取所有聚合支付记录
     */
    PageInfo<SysCompanyFusionPayRecordVo> getFusionPayRecordByCtrlAccount(SysCompanyFusionPayRecordSearchVo sysCompanyFusionPayRecordSearchVo, CtrlAccountPO ctrlAccountPO);

    /**
     * 获取企业下所有聚合支付记录
     */
    PageInfo<SysCompanyFusionPayRecordVo> getFusionPayRecordByCompanyId(SysCompanyFusionPayRecordSearchVo sysCompanyFusionPayRecordSearchVo);


    /**
     * 审核支付宝服务商-初审
     */
    ResponseData firstAuditFusionPayRecordAlipayProviders(AlipayProvidersBizvaneAuditVo alipayProvidersAuditVo, CtrlAccountPO ctrlAccountPO);

    /**
     * 审核支付宝服务商-复审
     */
    ResponseData secondAuditFusionPayRecordAlipayProviders(AlipayProvidersPlatformAuditVo alipayProvidersPlatformAuditVo, CtrlAccountPO ctrlAccountPO);

    /**
     * 更新聚合支付记录-备注名
     */
    ResponseData modifyFusionPayRecordRemarkName(SysCompanyFusionPayRecordPo sysCompanyFusionPayRecordPo);

    /**
     * 新增支付宝商户
     */
    ResponseData addAlipayMerchant(FusionPayAlipayMerchantVo fusionPayAlipayMerchantVo);

    /**
     * 更新支付宝商户
     */
    ResponseData modifyAlipayMerchant(FusionPayAlipayMerchantVo fusionPayAlipayMerchantVo);

    /**
     * 新增支付宝服务商
     */
    ResponseData addAlipayProviders(FusionPayAlipayProvidersVo fusionPayAlipayProvidersVo);

    /**
     * 更新支付宝服务商
     */
    ResponseData modifyAlipayProviders(FusionPayAlipayProvidersVo fusionPayAlipayProvidersVo);


    /**
     * 新增微信商户
     */
    ResponseData addWxPayMerchant(FusionPayWxPayMerchantVo fusionPayWxPayMerchantVo);

    /**
     * 修改微信商户
     */
    ResponseData modifyWxPayMerchant(FusionPayWxPayMerchantVo fusionPayWxPayMerchantVo);


    /**
     * 新增微信银联
     */
    ResponseData addWxPayUnion(FusionPayWxPayUnionVo fusionPayWxPayUnionVo);

    /**
     * 修改微信银联w
     */
    ResponseData modifyWxPayUnion(FusionPayWxPayUnionVo fusionPayWxPayUnionVo);

    /**
     * 查询聚合支付信息
     */
    ResponseData<FusionPayRecordWrapperVo> getFusionPayInfoByRecordId(FusionPayRecordRequestWrapperVo fusionPayRecordRequestWrapperVo);

    /**
     * 支付宝服务商授权回调成功更新数据
     */
    Integer modifyAlipayProvidersAppIdByPid(String pid,String appId,Integer alipayProvidersId);
}
